@@ -15,7 +15,7 @@ from .versions import VersionRaw, guess_version
 from .meta import Meta, MetaRaw, MetaFactory
 from .errors import PinsError
 from .drivers import load_data, save_data, default_title
-from .utils import inform, ExtendMethodDoc
+from .utils import inform, warn_deprecated, ExtendMethodDoc
 from .config import get_allow_rsc_short_name
 
 
@@ -255,6 +255,14 @@ class BaseBoard:
             part of the pin version name.
         """
 
+        if type == "feather":
+            warn_deprecated(
+                'Writing pin type "feather" is unsupported. Switching type to "arrow".'
+                " This produces the exact same behavior, and also works with R pins."
+                ' Please switch to pin_write using type="arrow".'
+            )
+            type = "arrow"
+
         pin_name = self.path_to_pin(name)
 
         # TODO(docs): describe options for type argument
@@ -897,6 +905,8 @@ class BoardRsConnect(BaseBoard):
             return self._user_name
 
     def prepare_pin_version(self, pin_dir_path, x, name: "str | None", *args, **kwargs):
+        # TODO: should move board_deparse into utils, to avoid circular import
+        from .constructors import board_deparse
 
         # RSC pin names can have form <user_name>/<name>, but this will try to
         # create the object in a directory named <user_name>. So we grab just
@@ -931,6 +941,7 @@ class BoardRsConnect(BaseBoard):
             "pin_name": self.path_to_pin(name),
             "pin_files": pin_files,
             "pin_metadata": meta,
+            "board_deparse": board_deparse(self),
         }
 
         # data preview ----
@@ -943,13 +954,21 @@ class BoardRsConnect(BaseBoard):
 
         if isinstance(x, pd.DataFrame):
             # TODO(compat) is 100 hard-coded?
+            # Note that we go df -> json -> dict, to take advantage of pandas type conversions
             data = json.loads(x.head(100).to_json(orient="records"))
             columns = [
                 {"name": [col], "label": [col], "align": ["left"], "type": [""]}
                 for col in x
             ]
 
-            context["data_preview"] = json.dumps({"data": data, "columns": columns})
+            # this reproduces R pins behavior, by omitting entries that would be null
+            data_no_nulls = [
+                {k: v for k, v in row.items() if v is not None} for row in data
+            ]
+
+            context["data_preview"] = json.dumps(
+                {"data": data_no_nulls, "columns": columns}
+            )
         else:
             # TODO(compat): set display none in index.html
             context["data_preview"] = json.dumps({})
